@@ -3,7 +3,7 @@ IMGO - Process, augment, and balance image data.
 ------------------------------------------------
 UPTOOLS module: 
 
-Last updated: version 2.3.5
+Last updated: version 2.3.6
 
 Classes
 -------
@@ -1066,18 +1066,26 @@ class Image_Dataset:
                                 ((combo_sets[k][0][i] - img_min) * 255)
                                 / (img_max - img_min)
                             ).astype(np.uint8)
-                            clean_img = np.clip(raw_img, 0, 255)
+                            clean_img = np.clip(raw_img, 0, 255).astype(
+                                np.uint8
+                            )
                         elif self.expand == "de_norm":
                             raw_img = (
                                 combo_sets[k][0][i] * 255
                             ).astype(np.uint8)
-                            clean_img = np.clip(raw_img, 0, 255)
+                            clean_img = np.clip(raw_img, 0, 255).astype(
+                                np.uint8
+                            )
                         else:
                             raw_img = combo_sets[k][0][i]
-                            clean_img = np.clip(raw_img, 0, 255)
+                            clean_img = np.clip(raw_img, 0, 255).astype(
+                                np.uint8
+                            )
                     else:
                         raw_img = combo_sets[k][0][i]
-                        clean_img = np.clip(raw_img, 0, 255)
+                        clean_img = np.clip(raw_img, 0, 255).astype(
+                            np.uint8
+                        )
 
                     if self.mode == "imgs":
                         img = clean_img
